const {
  csv,
  select,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} = d3;

// how to pull the data in JS and use async funcs
// need to copy the url, takes a sec
// csv(
//   // 'https://raw.githubusercontent.com/bepnye/CP341/main/world-data-2023.csv',
//   'https://raw.githubusercontent.com/WhteRabb-t/CP341-datavis/main/new_world-data-2023.csv',
// ).then((data) => {
//   // function to do after you recieve the data
//   console.log('I recieved the data');
//   console.log(data);
//   // render(data) // write a function call render
// });

// async and promises
const csvUrl =
  'https://raw.githubusercontent.com/WhteRabb-t/CP341-datavis/main/new_world-data-2023.csv';
// 'https://gist.githubusercontent.com/tejasri280/2487d19ed717c495acccef0d57120af6/raw/62c2b983372eb220d6b31f717e5eb48dda8665b9/PengBird.csv';
const parseRow = (d) => {
  d.GDP = +d.GDP;
  d['Gasoline Price'] = +d['Gasoline Price'];
  return d;
};

const xValue = (d) => d.GDP;
const yValue = (d) => d['Gasoline Price'];
const rxValue = (d) => d.GDP;
const ryValue = (d) => d['Gasoline Price'];

const margin = {
  top: 20,
  right: 30,
  bottom: 50,
  left: 80,
};
const radius = 4;

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// allows you to mouse over and get info?
const tooltip = select('body')
  .append('div')
  .classed('tooltip', true)
  .html('<h1></h1>');

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  // console.log(data);

  const x = scaleLinear()
    .domain(extent(data, xValue)) // tells you the lowest and highest values are to scale axis properly
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  svg
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cx', (d) => x(d.GDP)) // cx is this x value, this(GDP) column in the data
    .attr('cy', (d) => y(d['Gasoline Price'])) //cy is this y value, this(Gasoline) column in the data
    .attr('fill', (d) => d.color)
    .attr('rx', (d) => d.rx)
    .attr('ry', (d) => d.ry)
    .attr('r', radius)
    .on('mouseover', function (e, d) {
      // e= event d= element in the svg list
      console.log(e);
      console.log(d);
    });

  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(axisLeft(y));
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`,
    )
    .call(axisBottom(x));

  svg
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', innerWidth / 3.0)
    .attr('y', 30)
    .style('font', '45px times')
    .text('Scatter Plot');

  svg
    .append('text')
    .attr('class', 'x-label')
    .attr('x', width - 500)
    .attr('y', height - 10)
    .attr('text-anchor', 'middle')
    .style('font', '20px times')
    .text('x label');

  svg
    .append('text')
    .attr('class', 'y-label')
    .attr('y', 25)
    // .attr('dy', 'lem')
    .attr('x', 2 - height / 2)
    .attr('transform', 'rotate(-90)')
    .attr('text-anchor', 'middle')
    .style('font', '20px times')
    .text('y label');
};

main();
